/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.milter.actions.encryptor;

import org.slf4j.Logger;
import com.openexchange.exception.OXException;
import com.openexchange.guard.keymanagement.commons.RecipKey;
import com.openexchange.guard.keymanagement.services.RecipKeyService;
import com.openexchange.guard.keymanagement.services.impl.lookup.CompositeRecipKeyLookupStrategy;
import com.openexchange.guard.keymanagement.services.impl.lookup.GuardRecipKeyLookupStrategy;
import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrategy;
import com.openexchange.guard.milter.actions.MilterRcptAction;
import com.openexchange.guard.milter.osgi.Services;
import com.openexchange.guard.milter.service.MilterMail;

/**
 * {@link MilterRcptActionEncryptor}
 *
 * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
 * @since v2.8.0
 */
public class MilterRcptActionEncryptor implements MilterRcptAction {

    private static Logger Log = org.slf4j.LoggerFactory.getLogger(MilterRcptActionEncryptor.class);
    /* (non-Javadoc)
     * @see com.openexchange.guard.milter.actions.MilterRcptAction#handleRcpt(com.openexchange.guard.milter.service.MilterMail, java.lang.String)
     */
    @Override
    public boolean handleRcpt(MilterMail mail, String rcp) throws OXException {
        RecipKeyService recipKeyService = Services.getService(RecipKeyService.class);
        RecipKey key = recipKeyService.getRecipKey(new CompositeRecipKeyLookupStrategy(new RecipKeyLookupStrategy[] {
            new GuardRecipKeyLookupStrategy()
        }), getEmail(rcp), 0, 0);
        if (key == null || !key.getEncryptIncoming()) {  // If no key or encryption not enabled then end
            mail.setHandle(false);
            return false;
        }
        Log.debug("Incoming email encryption set for " + rcp);
        mail.addRecipientKey(key);
        return true;
    }

    private String getEmail (String rcp) {
        if (rcp != null) {
            rcp = rcp.replaceAll("<", "").replaceAll(">", "");
        }
        return rcp;
    }


}
