/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.file;

public class FileTyper {

    /**
     * Gets type from filename. If not found, return applicaiton/octet
     *
     * @param filename
     * @return
     */
    public static String getFileType(String filename) {
        return (getFileType(filename, "application/octet-stream"));
    }

    /**
     * Gets the filetype from the filename.
     * If not found, returns default
     *
     * @param filename
     * @param def
     * @return
     */
    public static String getFileType(String filename, String def) {
        if (filename != null) {
            filename = filename.replace(".pgp", "");
            int i = filename.lastIndexOf(".");
            if (i > 0) {
                String suffix = filename.substring(i + 1);
                switch (suffix) {
                    // images
                    case "jpg":
                        return ("image/jpg");
                    case "gif":
                        return ("image/gif");
                    case "png":
                        return ("image/png");
                    case "bmp":
                        return ("image/bmp");
                    case "heic":
                        return ("image/heic");
                    case "heif":
                        return ("image/heif");

                    // audio
                    case "wav":
                        return ("audio/wav");

                    // video
                    case "avi":
                        return ("video/avi");
                    case "mp4":
                        return ("video/mp4");
                    case "mpeg":
                        return ("video/mpeg");
                    case "wmv":
                        return ("video/x-ms-wmv");

                    // text/documents
                    case "txt":
                        return ("text/plain");
                    case "html":
                        return ("text/html");
                    case "rtf":
                        return ("text/rtf");
                    case "pdf":
                        return ("application/pdf");

                }
            }
        }
        return (def);
    }
}
