/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets.pgpcore;

import java.util.List;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.openexchange.pgp.core.PGPSignatureVerificationResult;
import com.openexchange.pgp.keys.tools.PGPKeysUtil;


/**
 * {@link VerifyResultJsonFactory}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public class VerifyResultJsonFactory {

    private static final String RESULTS_PROPERTY = "results";
    private static final String VERIFIED_PROPERTY = "verified";
    private static final String DATE_PROPERTY = "signatureCreatedOn";
    private static final String MISSING_PROPERTY = "missing";
    private static final String ERROR_PROPERTY = "error";
    private static final String ISSUER_USERIDS_PROPERTY = "issuerUserIds";
    private static final String ISSUER_KEY_FINGERPRINT_PROPERTY = "issuerKeyFingerprint";
    private static final String ISSUER_KEY_ID_PROPERTY = "issuerKeyId";

    public static JsonElement toJson(List<PGPSignatureVerificationResult> results) {
        JsonObject json = new JsonObject();
        JsonArray array = new JsonArray();
        for(PGPSignatureVerificationResult result : results) {
            array.add(toJson(result));
        }
        json.add(RESULTS_PROPERTY, array);
        return json;
    }

    public static JsonElement toJson(PGPSignatureVerificationResult result) {
        JsonObject json = new JsonObject();
        json.addProperty(VERIFIED_PROPERTY, result.isVerified());
        json.addProperty(DATE_PROPERTY, result.getSignature().getCreationTime().getTime());
        json.addProperty(MISSING_PROPERTY, result.isMissing());
        if(result.getIssuerKey() != null) {
            json.addProperty(ISSUER_KEY_ID_PROPERTY, result.getIssuerKey().getKeyID());
            json.addProperty(ISSUER_KEY_FINGERPRINT_PROPERTY, PGPKeysUtil.getFingerPrint(result.getIssuerKey().getFingerprint()));
        }
        List<String> userIds = result.getIssuerUserIds();
        JsonArray userIdsArray = new JsonArray(userIds.size());
        for(String userId : userIds) {
           userIdsArray.add(userId);
        }
        json.add(ISSUER_USERIDS_PROPERTY, userIdsArray);
        json.addProperty(ERROR_PROPERTY, result.getError());
        return json;
    }
}
